@@ -8,8 +8,6 @@ from typing import Iterator
 
 from maus.edifact import EdifactFormat, EdifactFormatVersion
 
-from ahbicht.content_evaluation.content_evaluation_result import ContentEvaluationResult, ContentEvaluationResultSchema
-
 #: the default edifact format used in the unit tests
 from ahbicht.content_evaluation.evaluationdatatypes import EvaluatableData
 from ahbicht.content_evaluation.fc_evaluators import FcEvaluator
@@ -27,21 +25,6 @@ empty_default_test_data: EvaluatableData = EvaluatableData(
 )
 
 
-def store_content_evaluation_result_in_evaluatable_data(
-    content_evaluation_result: ContentEvaluationResult,
-) -> EvaluatableData:
-    """
-    a helper method for the tests so store a serialized content evaluation result in an EvaluatableData instance
-    :param content_evaluation_result:
-    :return: a new EvaluatableData instance
-    """
-    schema = ContentEvaluationResultSchema()
-    cer_dict = schema.dump(content_evaluation_result)
-    return EvaluatableData(
-        edifact_seed=cer_dict, edifact_format=default_test_format, edifact_format_version=default_test_version
-    )
-
-
 class EmptyDefaultRcEvaluator(RcEvaluator):
     """
     An RC Evaluator in the default edifact format and edifact format version
